@../src/read
@natconst
close,1

mstar = MS                       ; Stellar mass in gram
rstar = RS                       ; Stellar radius in cm
tstar = TS                       ; Stellar temperature in K
r     = [1] * AU                 ; Radial grid points
sig0  = 100.                     ; Surface density of the gas at 1 AU
pls   = -1.                      ; Power law index for surface density of the gas
sigg  = sig0*(r/AU)^pls          ; Surface density of the gas
flang = 0.05                     ; Flaring radiation incidence angle
nz    = 40                       ; Number of z- grid points 
zmxhp = 6.                       ; Upper boundary of z, in units of pressure scale height of disk
alph0 = 0.0001                   ; Turbulent alpha
dtog  = 0.01                     ; Dust to gas ratio
cfl   = 0.5                      ; CFL number
nsm   = 10000                    ; Max nr of sub time steps for evap/cond
;ifl   = 0                       ; Flux limiter
ifl   = -1                       ; Flux limiter
;
; Now the basic silicate dust
;
agr   = [1.d0] * 1d-4            ; Sizes of the grains
wgt   = [1.d0]                   ; Just arbitrary weighting, still needs to be normalized to dust-to-gas ratio
wgt   = dtog * wgt / total(wgt)  ; Normalizing
swgr  = 2.                       ; Specific weight of the dust material in g/cm^3
mgr   = (4.*pi/3.)*swgr*agr^3    ; Computed mass of the grains assuming compact grains
ns0   = n_elements(agr)
;
; Now add water ice mantels of varying thickness
;
nice   = 100
swgice = 1.
iceinc = 0.01
agrice = dblarr(nice,ns0)
mgrice = dblarr(nice,ns0)
wgtice = dblarr(nice,ns0)
for is=0,ns0-1 do begin
   agrice[*,is] = agr[is] * (1.d0+iceinc)^(dindgen(nice))
   mgrice[*,is] = mgr[is] + (4.*pi/3.) * swgice * (agrice[*,is]^3-agr[is]^3)
   wgtice[0,is] = wgt[is]
endfor
ns = ns0 * nice
;
; How much gas phase water (by mass)?
;
wgth2o = 0.5d-2
;
; Time stepping stuff
; 
time_end = 1d0 * year            ; End of simulation in seconds model time
time_dtt = 0.1                   ; Time step in units of time itself 

nsave  = 20                      ; Number of saves
ts1    = time_end                ; Last save
ts0    = 1 * year                ; First save
;time_dtsave = time_end / nsave
tsaves = ts0 * (time_end/ts0)^((dindgen(nsave)+1.d0)/nsave)

;--------------------------------------------------------------

nr    = n_elements(r)
tmid  = sqrt(0.5d0)*sqrt(rstar/r)*flang^0.25*tstar
omk   = sqrt(GG*mstar/r^3)
cs2   = kk*tmid/(2.3*mp)
cs    = sqrt(cs2)
hp    = cs/omk

z     = dblarr(nz,nr)
rhog  = dblarr(nz,nr)
nd    = dblarr(ns,nz,nr)
for ir=0,nr-1 do begin
   z[*,ir]    = zmxhp * hp[ir] * dindgen(nz) / (nz-1.d0)
   rhog[*,ir] = ( sigg[ir] / (sqrt(2*!pi)*hp[ir]) ) * exp(-0.5d0 * z[*,ir]^2 / hp[ir]^2)
   for is=0,ns-1 do begin
      ;; NOTE: WE CONVERT HERE TO NUMBER DENSITY!
      nd[is,*,ir] = rhog[*,ir] * wgtice[is] / mgrice[is]
   endfor
endfor
rhoh2o = rhog * wgth2o
mh2o   = (16+2)*mp
nh2o   = rhoh2o / mh2o

alpha = dblarr(nz,ir) + alph0

;
; Write the diskmixsett.inp file
;
openw,1,'diskmixsett.inp'
printf,1,'star_m      = ',mstar
printf,1,'time_end    = ',time_end
if n_elements(tsaves) ge 1 then begin
   printf,1,'time_dtsave = ',0.d0
   openw,2,'savetimes.inp'
   printf,2,n_elements(tsaves)
   for i=0,n_elements(tsaves)-1 do printf,2,tsaves[i]
   close,2
endif else begin
   printf,1,'time_dtsave = ',time_dtsave
   spawn,'\rm -rf savetimes.inp'
endelse
printf,1,'time_dtt    = ',time_dtt
printf,1,'userdef_nscond = ',nice
printf,1,'userdef_cfl = ',cfl
printf,1,'userdef_nstepmax = ',nsm
printf,1,'userdef_ifluxlim = ',ifl
printf,1,'incl_mixing = 0'
printf,1,'incl_settling = 0'
printf,1,'nstepsave = 1'
printf,1,'maxnrsave = 10'
close,1
;
; Write the gas density and temperature
;
openw,1,'diskstruct.inp'
printf,1,nr,nz
for ir=0,nr-1 do begin
   for iz=0,nz-1 do printf,1,r[ir],z[iz,ir],rhog[iz,ir],tmid[ir],0.d0
endfor
close,1
;
; Write the alpha(z)
;
openw,1,'auxvar.inp'
printf,1,1          ; Format number
printf,1,nr,nz       ; Nr and Nz
for ir=0,nr-1 do begin
   for iz=0,nz-1 do printf,1,alpha[iz,ir]
endfor
close,1
;
; Write the dust initial density
;
openw,1,'dustdens.inp'
printf,1,1          ; Format number
printf,1,nr,nz      ; Nr, Nz
printf,1,ns         ; Nr dust species
for ir=0,nr-1 do begin
   for iz=0,nz-1 do begin
      printf,1,nd[*,iz,ir]
   endfor
endfor
close,1
;
; Write the dust properties
;
openw,1,'dustinfo.inp'
printf,1,1           ; Format number
printf,1,ns          ; Nr of dust species
for is=0,ns-1 do printf,1,agrice[is],mgrice[is]
close,1
;
; Now add gas-phase water as a chemical species 
;
openw,1,'chemdens.inp'
printf,1,1          ; Format number
printf,1,nr,nz      ; Nr, Nz
printf,1,1          ; One gas phase water species
for ir=0,nr-1 do begin
   for iz=0,nz-1 do begin
      printf,1,nh2o[iz,ir]
   endfor
endfor
close,1
;
; Now run the code
;
;spawn,'../src/diskmixsett'
spawn,'./diskmixsett'
;
; Read the output
;
a=read()
;
; Make a plot (try out any of the below by uncommenting it)
;
ir=0
is=0
it=n_elements(a.rhodust[0,0,0,*])-1
;
; Plot dust and gas densities for dust species 0 and at various times
;
;plot,a.z[*,ir]/a.r[ir],a.rhogas[*,ir],/yl
;for it=0,n_elements(a.time)-1 do oplot,a.z[*,ir]/a.r[ir],a.rhodust[is,*,ir,it]
;
; Plot dust / gas density ratio for dust species 0 and at various times
;
;plot,a.z[*,ir]/a.r[ir],a.rhodust[is,*,ir,0]/a.rhogas[*,ir],yrange=[1d-8,1d-1],/ys,/yl
;for it=0,n_elements(a.time)-1 do oplot,a.z[*,ir]/a.r[ir],a.rhodust[is,*,ir,it]/a.rhogas[*,ir]
;
; Plot dust / gas density ratio for the last time point, for various dust species 
;
plot,a.z[*,ir]/a.r[ir],a.rhodust[0,*,ir,1]/a.rhogas[*,ir],/ys,/yl
for is=0,n_elements(a.rhodust[*,0,0,0])-1 do oplot,a.z[*,ir]/a.r[ir],a.rhodust[is,*,ir,it]/a.rhogas[*,ir]
;
; Plot dust / gas density ratio for the last time point, for dust species 0,
; at different radii
;
;plot,a.z[*,ir]/a.r[ir],a.rhodust[0,*,ir,0]/a.rhogas[*,ir],yrange=[1d-8,1d-1],/ys,/yl
;for ir=0,n_elements(a.rhodust[0,0,*,0])-1 do oplot,a.z[*,ir]/a.r[ir],a.rhodust[is,*,ir,it]/a.rhogas[*,ir]
;
;
end
