;---------------------------------------------------------------------------
;    Make opacities for a size distribution (dispersed, not summed)
;---------------------------------------------------------------------------
pro make_opacs,amicron,optconst,swgt,nu
cc  = 2.9979245800000d10      ; Light speed             [cm/s]
;
nf      = n_elements(nu)
na      = n_elements(amicron)
;
; We write the wavelength grid for the dust opacity code
;
openw,1,'frequency.inp'
printf,1,nf
printf,1,' '
for inu=0,nf-1 do printf,1,nu[inu]
close,1
;
; We tell the dust opacity code which dust opacities to make
;
openw,1,'dust.inp'
for ia=0,na-1 do begin
   printf,1,optconst
   printf,1,'"MIE"'
   q = alog10(amicron[ia])
   printf,1,'1  0.0 ',q,q,' 1 -3.5 ',swgt,' -2.0'
endfor
close,1
;
; Main command file
;
openw,1,'makeopac.inp'
printf,1,'opac'
close,1
;
; We call the dust opacity code
;
spawn,'../makedust/makedust'
;
end


;--------------------------------------------------------------------------
;                       Set up the frequency array
;--------------------------------------------------------------------------
function problem_frequencies,fresmd
;
; Make the frequency array
;   (There is a discrete set of possible frequency grid resolution modes)
; 
if n_elements(fresmd) eq 0 then fresmd=0
case fresmd of
   0: begin
      lambda0  = 1d4
      lambda1  = 50.0
      lambda2  = 6.0
      lambda3  = 0.1
      nfrnew01 = 24
      nfrnew12 = 22
      nfrnew23 = 20
   end
   1: begin
      lambda0  = 1d4
      lambda1  = 50.0
      lambda2  = 6.0
      lambda3  = 0.1
      nfrnew01 = 20
      nfrnew12 = 80
      nfrnew23 = 20
   end
   2: begin            ; Freq-grid used for the group I/II simuls (BB-star)
      lambda0  = 1d4
      lambda1  = 30.0
      lambda2  = 6.0
      lambda3  = 0.1
      nfrnew01 = 20
      nfrnew12 = 26
      nfrnew23 = 19
   end
   3: begin            ; Freq-grid used for the group I/II simuls (Kurucz)
      lambda0  = 1d4
      lambda1  = 30.0
      lambda2  = 5.5
      lambda3  = 0.1  
      nfrnew01 = 20
      nfrnew12 = 30
      nfrnew23 = 30 
   end
   4: begin            ; Freq-grid used for the group I/II simuls (Kurucz)
      lambda0  = 1d4
      lambda1  = 30.0
      lambda2  = 7.0
      lambda3  = 0.1  
      nfrnew01 = 20
      nfrnew12 = 30
      nfrnew23 = 30 
      freq_hardcode = [4.28E+13,4.54E+13,4.84E+13,5.0E+13,5.17E+13,5.450723E+13,6.258446E+13,7.185862E+13,7.89E+13,8.250724E+13,8.8e+13,9.473368E+13,9.677E+13,1.087719E+14,1.248904E+14,1.38888E+14,1.646470E+14,1.8181818E+14,2.170594E+14,2.400000E+14,2.861575E+14,3.285621E+14,3.772505E+14,4.331539E+14,4.973413E+14,5.710405E+14,6.556609E+14,7.528209E+14,8.643787E+14,9.924678E+14,1.139538E+15,1.308407E+15,1.502295E+15,1.724914E+15,1.980523E+15,2.274010E+15,2.610987E+15,2.997899E+15]
   end
   30: begin            ; For the crystalline features
      lambda0  = 1d4
      lambda1  = 40.0
      lambda2  = 5.5
      lambda3  = 0.1  
      nfrnew01 = 20
      nfrnew12 = 80
      nfrnew23 = 30 
   end
   31: begin            ; For the crystalline features
      lambda0  = 1d4
      lambda1  = 75.0
      lambda2  = 8.0
      lambda3  = 0.1  
      nfrnew01 = 20
      nfrnew12 = 200
      nfrnew23 = 30 
   end
   else: begin
      print,"Do not know this frequency resolution mode"
      stop
   endelse
endcase
cc       = 2.9979e10
freq0    = 1e4*cc/lambda0
freq1    = 1e4*cc/lambda1
freq2    = 1e4*cc/lambda2
freq3    = 1e4*cc/lambda3
dlfreq01 = alog(freq1)-alog(freq0)
dlfreq12 = alog(freq2)-alog(freq1)
dlfreq23 = alog(freq3)-alog(freq2)
freqnw01 = exp((findgen(nfrnew01)/(nfrnew01))*dlfreq01+alog(freq0))
freqnw12 = exp((findgen(nfrnew12)/(nfrnew12))*dlfreq12+alog(freq1))
freqnw23 = exp((findgen(nfrnew23)/(nfrnew23-1.e0))*dlfreq23+alog(freq2))
IF fresmd EQ 4 then freqnw23=freq_hardcode  ;Forcing specific frequency points to get exact jhk photometry.
freqnew  = [freqnw01,freqnw12,freqnw23]
nf       = n_elements(freqnew)
;
; Write the frequency data file
;
return,freqnew
end
