@problem_radmc_grid.pro
@problem_radmc_subroutines.pro
@problem_radmc_kurucz.pro
@problem_makeopac.pro

pro setup_radmc,r,z,mgr,agr,rhodustorig,nrr,ntt,rstar,mstar,tstar,kurucz,$
                hrgmax=hrgmax,ntextra=ntextra,nphot=nphot,optconst=optconst,$
                optswgt=optswgt,rhofloor=rhofloor,enthres=enthres,hrgrid=hrgrid,$
                iim=iim,zrsmear=zrsmear,zrref=zrref,nzref=nzref,$
                dmass=dmass,iquant=iquant,rminpah=rminpah,$
                rrefine=rrefine,kuruczdir=kuruczdir,redux=redux,$
                ifinstar=ifinstar,drsm=drsm,tautol=tautol,fresmd=fresmd
;;
;; Default parameters
;;
if n_elements(iquant) eq 0 then iquant=0
if n_elements(hrgmax) eq 0 then hrgmax=0.9*!pi/2.d0
if n_elements(rhofloor) eq 0 then rhofloor = 1d-50
if n_elements(nphot) eq 0 then nphot = 100000
if n_elements(enthres) eq 0 then enthres = 0.01
if n_elements(ifinstar) eq 0 then ifinstar=0
if n_elements(ntextra) eq 0 then ntextra = 10
if n_elements(optconst) eq 0 then optconst = 'amorphsilicate.lnk'
if n_elements(optswgt) eq 0 then optswgt = 1.8
;
; Interpret the iim rebinning parameter
;
if n_elements(iim) eq 0 then begin
   iim = floor(findgen(n_elements(mgr)))
endif
nmm = max(iim)+1
;
; Go from rhodustorig (g cm^{-3}) to rhodustrebin (g cm^{-3})
; Each dust size now corresponds to an independent dust component
; with a given density (the mgr integration interval is already 
; included!) 
;
; ************************************************************
; NOTE: HERE WE ALREADY DO THE REBINNING FOR SPEEDING UP RADMC
; ************************************************************
;
nm         = n_elements(mgr)
if not keyword_set(dmass) then begin
    ;;
    ;; Make the mass bin size out of the mass grid spacing
    ;;
    dmgr       = mgr*0.d0
    dmgr[0]    = 0.5 * (mgr[1]-mgr[0])
    dmgr[nm-1] = 0.5 * (mgr[nm-1]-mgr[nm-2])
    for i=1,nm-2 do dmgr[i] = 0.5 * (mgr[i+1]-mgr[i-1])
endif else begin
    ;;
    ;; For the case of 1 or 2 mass bins, the mass bin size can
    ;; be specified by the user.
    ;;
    dmgr       = dmass
endelse
sss=size(rhodustorig)
if sss[0] ne 3 then stop 
rhodustrebin = dblarr(nmm,sss[2],sss[3])
for i=0,nm-1 do begin
   rhodustrebin[iim[i],*,*] = rhodustrebin[iim[i],*,*] + $
                              rhodustorig[i,*,*] ;; * mgr[i] * dmgr[i]
endfor
;
; Big grains settle down into a thin midplane layer. This cannot
; be resolved by RADMC and RADICAL. Smooth midplane out.
;
if keyword_set(zrsmear) then begin
   for ir=0,n_elements(r)-1 do begin
      hunt,z[*,ir],zrsmear*r[ir],iz
      for i=0,nmm-1 do begin
         rhodustrebin[iim[i],0:iz,ir] = $
              integrate(z[0:iz,ir],rhodustrebin[iim[i],0:iz,ir])/z[iz,ir]
      endfor
   endfor
endif
;
; Add ab absolute floor to the dust density
;
absfloor = 1d-100
rhodust  = rhodustrebin + absfloor
;
; Now find the average dust mass and size for each rebinned bin
;
dumm=dblarr(nmm)
agrav=dblarr(nmm)
mgrav=dblarr(nmm)
agrav=dblarr(nmm)
for i=0,nm-1 do begin
   dumm[iim[i]]=dumm[iim[i]]+1
   mgrav[iim[i]]=mgrav[iim[i]]+mgr[i]
   agrav[iim[i]]=agrav[iim[i]]+agr[i]
endfor
for i=0,nmm-1 do begin
   mgrav[i]=mgrav[i]/dumm[i]
   agrav[i]=agrav[i]/dumm[i]
endfor
;
; Set up the opacities for the dust grains of the rebinned sizes
;
freq=problem_frequencies(fresmd)
make_opacs,agrav*1d4,optconst,optswgt,freq
;;
;; Find the stuff
;;
nr = n_elements(r)
nz = n_elements(z[*,0])
;;
;; Find out the largest zmax/r ratio
;;
if n_elements(hrgrid) eq 0 then begin
   hrgrid = 0.d0
   for ir=0,nr-1 do begin
      if z[nz-1,ir]/r[ir] gt hrgrid then hrgrid = z[nz-1,ir]/r[ir]
   endfor
endif
;;
;; Set up the radial grid
;; BUGFIX: 04.01.07
;;         I used to do this shifting by 1d-4, but I think this is
;;         messy and could cause problems lateron. I now solve the
;;         interpolation problem differently.
;;
;;;;;;rr    = make_rgrid(min(r)*(1+1d-4),max(r)*(1-1d-4),nrr,rrefine=rrefine)
;
rr    = make_rgrid(min(r),max(r),nrr,rrefine=rrefine)
;;
;; Set up the Theta grid
;;
theta = make_tgrid(hrgrid,ntt,hrgmax=hrgmax,ntex=ntextra,$
                    hrlg=hrlg,zrefine=zrefine)
nnt   = n_elements(theta)
;;
;; Put the dust density on a grid
;;
rho=dblarr(nnt,nrr,nmm)
for im=0,nmm-1 do begin
    ;;
    ;; Sometimes you may want to exclude the PAHs from the inner rim
    ;; regions. This can be done here...
    rmin = 0.d0
    if im eq 0 and keyword_set(rminpah) then rmin=rminpah
    ;; 
    ;; Now loop over r
    ;;
    ;; BUGFIX: 04.01.07
    ;;  I now avoid the boundary problems here (see BUGFIX: 04.01.07 above)
    ;;
    for ir=0,nrr-1 do begin
        ;;;;;;        if rr[ir] ge rmin then begin
        if rr[ir] ge rmin*(1.d0-1.d-4) then begin
            ;;
            ;; Find the location of this radius in the input array
            ;;
            ;; BUGFIX: 04.01.07
            ;;  I now avoid the boundary problems here (see BUGFIX: 04.01.07 above)
            ;;
            ;; MODIF: 09.07.10
            ;;  I now interpolate in log(r) instead of in r. Useful for
            ;;  cases where r has only a few points.
            hunt,alog(r),alog(rr[ir]),irip,epsr
            ;;if(irip lt 0) then stop
            ;;if(irip ge nr-1) then stop
            if(irip lt 0) then begin
               irip=0
               epsr=0.d0
            endif
            if(irip ge nr-1) then begin
               irip=nr-2
               epsr=1.d0
            endif
            ;;
            ;; Find the rho in left slab
            ;;
            rholeft = dblarr(nnt)
            for it=0,nnt-1 do begin
                hunt,z[*,irip],r[irip]*(!pi/2-theta[it]),izip,epsz
                if(izip lt 0) then stop
                if(izip ge nz-1) then begin
                    rholeft[it]=absfloor 
                endif else begin
                    rholeft[it]=exp((1-epsz)*alog(rhodust[im,izip,irip])+$
                                    epsz*alog(rhodust[im,izip+1,irip]))
                endelse
            endfor
            ;;
            ;; Find the rho in right slab
            ;;
            rhoright = dblarr(nnt)
            for it=0,nnt-1 do begin
                hunt,z[*,irip+1],r[irip+1]*(!pi/2-theta[it]),izip,epsz
                if(izip lt 0) then stop
                if(izip ge nz-1) then begin
                    rhoright[it]=absfloor 
                endif else begin
                    rhoright[it]=exp((1-epsz)*alog(rhodust[im,izip,irip+1])+$
                                     epsz*alog(rhodust[im,izip+1,irip+1]))
                endelse
            endfor
            ;;
            ;; Do the averaging
            ;;
            rho[*,ir,im] = exp((1-epsr)*alog(rholeft) + epsr*alog(rhoright))
            ;;
        endif
        ;;
   endfor
endfor
;
; Add a floor to the dust density
;
rho = rho + rhofloor
;
; If requested, include a reduction array
; CAREFUL: THE REDUX ARRAY IS STILL IN THE IT,IR ORDER, BUT THE
;  DENSITY WILL BE SWAPPED BELOW... 27.04.07
;
if n_elements(redux) gt 0 then begin
   print,'Cutting away dead PAHs...'
   rho = rho * redux
endif
;
; Now transpose rho to the usual form (ir,it,ispec)
;
s=size(rho)
if s[0] eq 3 then begin
   rho = transpose(rho,[1,0,2])
endif else begin
   rho = transpose(rho,[1,0])
endelse
;
; Read the opacity to find the frequency grid
;
o=readopac()
nf = n_elements(o.freq)
;
; Now make sure that the inner rim optical depth is not too large
;
; ...First find the 0.55 micron on the freq grid
;
hunt,o.freq,2.9979d14/0.55,inu,eps
;
; ...Then find all the kappas at that freq
;
kappav=dblarr(nmm)
for im=0,nmm-1 do begin
   o=readopac(nr=stringint(im+1))
   nf = n_elements(o.freq)
   kappav[im]=o.cabs[inu]+o.csca[inu]
endfor
;
; ...Now call the smooth_rim() routine
;
smooth_rim,rr,theta,rho,kappav,drsm=drsm,tautol=tautol
;
; Write the dust density to a file for RADMC
;
openw,1,'radius.inp'
printf,1,nrr
printf,1,' '
for i=1,nrr do printf,1,rr[i-1]
close,1
openw,1,'theta.inp'
printf,1,nnt,1
printf,1,' '
for i=1,nnt do printf,1,theta[i-1]
close,1
openw,1,'dustdens.inp'
printf,1,nmm,nrr,nnt,1
printf,1,' '
for im=1,nmm do begin
   print,'Setting up 2-D RADMC component im=',im
   for ir=1,nrr do begin
      for it=1,nnt do begin
         printf,1,rho[ir-1,it-1,im-1]
      endfor
   endfor
endfor
close,1
;
; Make the starspec.inp
;
pc=3.08572d18
if keyword_set(kurucz) then begin
   RS  = 6.96d10               ; Solar radius            [cm]
   TS  = 5.78d3                ; Solar temperature       [K]
   LS  = 3.8525d33             ; Solar luminosity        [erg/s]
   lstar = LS * (rstar/RS)^2 * (tstar/TS)^4
   kurucz,tstar,lstar,mstar,/worig,kuruczdir=kuruczdir
endif else begin
   openw,1,'starspectrum.inp'
   printf,1,nf
   printf,1,' '
   for inu=0,nf-1 do begin
      printf,1,o.freq[inu],3.14159265359 * (rstar^2/pc^2) $
             * bplanck(o.freq[inu],tstar)
   endfor
   close,1
endelse
;
; Make starinfo.inp
;
if not keyword_set(mstar) then mstar=1.99d33
openw,1,'starinfo.inp'
printf,1,'1'
printf,1,rstar
printf,1,mstar
printf,1,tstar
close,1
;
; Make radmc.inp
;
openw,1,'radmc.inp'
printf,1,2
printf,1,nphot
printf,1,1
printf,1,-17933201
printf,1,2
printf,1,1
printf,1,enthres
printf,1,100000000
printf,1,0
printf,1,1            ; Decouple temperatures
printf,1,iquant       ; Include quantum-heating of small grains?
printf,1,ifinstar     ; Include finite size of the star!
close,1
;
; Now write raytrace.inp
;
;openw,1,'raytrace.inp'
;close,1
;
end
