@../src/read
@problem_radmc_setup.pro
@natconst
close,1
;
; Parameters of the model
;
mstar  = MS                       ; Stellar mass in gram
rstar  = RS                       ; Stellar radius in cm
tstar  = TS                       ; Stellar temperature in K
rin    = 0.1*AU                   ; Inner radius of disk
rout   = 100*AU                   ; Outer radius of disk
nr     = 30                       ; Nr of grid points in radial direction
alph0  = 0.01d0                 ; Viscous alpha
;prndtl = 1.d0                     ; Schmidt/Prandtl number
flang  = 0.05d0                   ; Flaring angle
mdot   = 1d-9*MS/year             ; Accretion rate
dtog   = 0.01d0                   ; Dust-to-gas ratio
nz     = 40                       ; Number of z- grid points 
zmxhp  = 6.                       ; Upper boundary of z, in units of pressure scale height of disk
agr    = [1.d0,1.d1,1.d2] * 1d-4  ; Sizes of the grains
wgt    = [1.d0,2.d0,4.d0]         ; Just arbitrary weighting, still needs to be normalized to dust-to-gas ratio
wgt    = dtog * wgt / total(wgt)  ; Normalizing
swgr   = 1.                       ; Specific weight of the dust material in g/cm^3
mgr    = (4.*pi/3.)*swgr*agr^3    ; Computed mass of the grains assuming compact grains
t_end  = 1d6 * year               ; End of simulation in seconds model time
t_dtt  = 0.1                      ; Time step in units of time itself 
nsave  = 20                       ; Number of saves
ts0    = 1 * year                 ; First save
ts1    = t_end                    ; Last save
;t_dts  = t_end / nsave
tsaves = ts0 * (t_end/ts0)^((dindgen(nsave)+1.d0)/nsave)
;
; Parameters for RADMC
;
nrr    = 120
ntt    = 60
;
;--------------------------------------------------------------
;              Make the radial structure of the disk
;--------------------------------------------------------------
;
r     = rin*(rout/rin)^(dindgen(nr)/(nr-1.d0))      ; Radial grid points
tmid  = sqrt(0.5d0)*(flang^0.25)*tstar*sqrt(rstar/r)
cs    = sqrt(kk*tmid/(2.3*mp))
omk   = sqrt(GG*mstar/r^3)
nu    = alph0*cs^2/omk
vr    = 1.5*nu/r/(1.d0-sqrt(r[0]/r)+1d-2)  ; ************** CHECK THIS *************
sigg  = mdot/(2*!dpi*r*vr)
;sigd  = sigg*dtog
;
;--------------------------------------------------------------
;                Now make the vertical structure 
;--------------------------------------------------------------
;
nr    = n_elements(r)
ns    = n_elements(agr)
hp    = cs/omk
z     = dblarr(nz,nr)
rhog  = dblarr(nz,nr)
rhod  = dblarr(ns,nz,nr)
for ir=0,nr-1 do begin
   z[*,ir]    = zmxhp * hp[ir] * dindgen(nz) / (nz-1.d0)
   rhog[*,ir] = ( sigg[ir] / (sqrt(2*!pi)*hp[ir]) ) * exp(-0.5d0 * z[*,ir]^2 / hp[ir]^2)
   for is=0,ns-1 do begin
      rhod[is,*,ir] = rhog[*,ir] * wgt[is]
   endfor
endfor
alpha = dblarr(nz,ir) + alph0
;
;
;
;
;--------------------------------------------------------------
; Now write all the files and do the dust settling calculation
;--------------------------------------------------------------
;
; Write the diskmixsett.inp file
;
openw,1,'diskmixsett.inp'
printf,1,'star_m      = ',mstar
printf,1,'time_end    = ',t_end
if n_elements(tsaves) ge 1 then begin
   printf,1,'time_dtsave = ',0.d0
   openw,2,'savetimes.inp'
   printf,2,n_elements(tsaves)
   for i=0,n_elements(tsaves)-1 do printf,2,tsaves[i]
   close,2
endif else begin
   printf,1,'time_dtsave = ',t_dts
   spawn,'\rm -rf savetimes.inp'
endelse
printf,1,'time_dtt    = ',t_dtt
close,1
;
; Write the gas density and temperature
;
openw,1,'diskstruct.inp'
printf,1,nr,nz
for ir=0,nr-1 do begin
   for iz=0,nz-1 do printf,1,r[ir],z[iz,ir],rhog[iz,ir],tmid[ir],0.d0
endfor
close,1
;
; Write the alpha(z)
;
openw,1,'auxvar.inp'
printf,1,1          ; Format number
printf,1,nr,nz       ; Nr and Nz
for ir=0,nr-1 do begin
   for iz=0,nz-1 do printf,1,alpha[iz,ir]
endfor
close,1
;
; Write the dust initial density
;
openw,1,'dustdens.inp'
printf,1,1          ; Format number
printf,1,nr,nz      ; Nr, Nz
printf,1,ns         ; Nr dust species
for ir=0,nr-1 do begin
   for iz=0,nz-1 do begin
      printf,1,rhod[*,iz,ir]
   endfor
endfor
close,1
;
; Write the dust properties
;
openw,1,'dustinfo.inp'
printf,1,1           ; Format number
printf,1,ns          ; Nr of dust species
for is=0,ns-1 do printf,1,agr[is],mgr[is]
close,1
;
; Now run the code
;
spawn,'../src/diskmixsett'
;
; Read the output
;
a=read()
;
; Make a plot (try out any of the below by uncommenting it)
;
;ir=0
;is=0
;it=n_elements(a.rhodust[0,0,0,*])-1
;
; Plot dust and gas densities for dust species 0 and at various times
;
;plot,a.z[*,ir]/a.r[ir],a.rhogas[*,ir],/yl
;for it=0,n_elements(a.time)-1 do oplot,a.z[*,ir]/a.r[ir],a.rhodust[is,*,ir,it]
;
; Plot dust / gas density ratio for dust species 0 and at various times
;
;plot,a.z[*,ir]/a.r[ir],a.rhodust[is,*,ir,0]/a.rhogas[*,ir],yrange=[1d-8,1d-1],/ys,/yl
;for it=0,n_elements(a.time)-1 do oplot,a.z[*,ir]/a.r[ir],a.rhodust[is,*,ir,it]/a.rhogas[*,ir]
;
; Plot dust / gas density ratio for the last time point, for various dust species 
;
;plot,a.z[*,ir]/a.r[ir],a.rhodust[0,*,ir,0]/a.rhogas[*,ir],yrange=[1d-8,1d-1],/ys,/yl
;for is=0,n_elements(a.rhodust[*,0,0,0])-1 do oplot,a.z[*,ir]/a.r[ir],a.rhodust[is,*,ir,it]/a.rhogas[*,ir]
;
; Plot dust / gas density ratio for the last time point, for dust species 0,
; at different radii
;
;plot,a.z[*,ir]/a.r[ir],a.rhodust[0,*,ir,0]/a.rhogas[*,ir],yrange=[1d-8,1d-1],/ys,/yl
;for ir=0,n_elements(a.rhodust[0,0,*,0])-1 do oplot,a.z[*,ir]/a.r[ir],a.rhodust[is,*,ir,it]/a.rhogas[*,ir]
;
; 
;--------------------------------------------------------------
;      Create the corresponding RADMC model for this
;--------------------------------------------------------------
;
itime = 20
setup_radmc,a.r,a.z,mgr,agr,a.rhodust[*,*,*,itime],nrr,ntt,$
                rstar,mstar,tstar,kurucz,optconst=optconst,$
                hrgmax=hrgmax,ntextra=ntextra,nphot=nphot,$
                rhofloor=rhofloor,enthres=enthres,hrgrid=hrgrid,$
                zrsmear=zrsmear,zrref=zrref,nzref=nzref,$
                dmass=dmass,iquant=iquant,rminpah=rminpah,$
                rrefine=rrefine,kuruczdir=kuruczdir,redux=redux,$
                ifinstar=ifinstar,drsm=drsm,tautol=tautol
;
end
