@../src/read
@natconst
close,1

mstar = MS                       ; Stellar mass in gram
rstar = RS                       ; Stellar radius in cm
tstar = TS                       ; Stellar temperature in K
r     = 1 * AU                   ; Radial grid point
sigg  = 100.                     ; Surface density of the gas
flang = 0.05                     ; Flaring radiation incidence angle
nz    = 40                       ; Number of z- grid points 
zmxhp = 6.                       ; Upper boundary of z, in units of pressure scale height of disk
alph0 = 0.0001                   ; Turbulent alpha
agr   = 10 * 1d-4                ; Sizes of the grains in cm
swgr  = 1.                       ; Specific weight of the dust material in g/cm^3
mgr   = (4.*pi/3.)*swgr*agr^3    ; Computed mass of the grains assuming compact grains

time_end = 1d6 * year            ; End of simulation in seconds
time_dtt = 0.1                   ; Time step in units of time itself 

nsave  = 20                      ; Nr of saves
ts1    = time_end                ; Last save
ts0    = 1 * year                ; First save
;time_dtsave = time_end / nsave
tsaves = ts0 * (time_end/ts0)^((dindgen(nsave)+1.d0)/nsave)

;--------------------------------------------------------------

tmid  = sqrt(0.5d0)*sqrt(rstar/r)*flang^0.25*tstar
omk   = sqrt(GG*mstar/r^3)
cs2   = kk*tmid/(2.3*mp)
cs    = sqrt(cs2)
hp    = cs/omk

z     = zmxhp * hp * dindgen(nz) / (nz-1.d0)
rhog  = ( sigg / (sqrt(2*!pi)*hp) ) * exp(-0.5d0 * z^2 / hp^2)
rhod  = transpose(rhog) * 0.01

alpha = dblarr(nz) + alph0

;
; Write the diskmixsett.inp file
;
openw,1,'diskmixsett.inp'
printf,1,'star_m      = ',mstar
printf,1,'time_end    = ',time_end
if n_elements(tsaves) ge 1 then begin
   printf,1,'time_dtsave = ',0.d0
   openw,2,'savetimes.inp'
   printf,2,n_elements(tsaves)
   for i=0,n_elements(tsaves)-1 do printf,2,tsaves[i]
   close,2
endif else begin
   printf,1,'time_dtsave = ',time_dtsave
   spawn,'\rm -rf savetimes.inp'
endelse
printf,1,'time_dtt    = ',time_dtt
close,1
;
; Write the gas density and temperature
;
openw,1,'diskstruct.inp'
printf,1,1,nz
for iz=0,nz-1 do printf,1,r,z[iz],rhog[iz],tmid,0.d0
close,1
;
; Write the alpha(z)
;
openw,1,'auxvar.inp'
printf,1,1          ; Format number
printf,1,1,nz       ; Nr and Nz
for iz=0,nz-1 do printf,1,alpha(iz)
close,1
;
; Write the dust initial density
;
openw,1,'dustdens.inp'
printf,1,1          ; Format number
printf,1,1,nz       ; Nr, Nz
printf,1,1          ; Nr dust species
for iz=0,nz-1 do begin
   printf,1,rhod[*,iz]
endfor
close,1
;
; Write the dust properties
;
openw,1,'dustinfo.inp'
printf,1,1           ; Format number
printf,1,1           ; Nr of dust species
printf,1,agr,mgr
close,1
;
; Now run the code
;
spawn,'../src/diskmixsett'
;
; Read the output
;
a=read()
;
; Make a plot
;
plot,a.z/a.r[0],a.rhogas[*,0],/yl
for it=0,n_elements(a.time)-1 do oplot,a.z/a.r[0],a.rhodust[0,*,0,it]
;
end
